[PATCH 2/2] spi: tegra: remove checks for valid speed

2013-01-04 Thread Laxman Dewangan
SPI core make sure that all transfer has proper speed set
before calling low level spi transfer. Hence, it is not
require to have check in spi driver.

Remove the check for speed validity from transfer and use it directly.

Signed-off-by: Laxman Dewangan ldewan...@nvidia.com
---
 drivers/spi/spi-tegra20-sflash.c |   14 +++---
 drivers/spi/spi-tegra20-slink.c  |6 +++---
 2 files changed, 14 insertions(+), 6 deletions(-)

diff --git a/drivers/spi/spi-tegra20-sflash.c b/drivers/spi/spi-tegra20-sflash.c
index 448a8cc..9a42c15 100644
--- a/drivers/spi/spi-tegra20-sflash.c
+++ b/drivers/spi/spi-tegra20-sflash.c
@@ -269,9 +269,7 @@ static int tegra_sflash_start_transfer_one(struct 
spi_device *spi,
u32 speed;
unsigned long command;
 
-   speed = t-speed_hz ? t-speed_hz : spi-max_speed_hz;
-   if (!speed)
-   speed = tsd-spi_max_frequency;
+   speed = t-speed_hz;
if (speed != tsd-cur_speed) {
clk_set_rate(tsd-clk, speed);
tsd-cur_speed = speed;
@@ -319,6 +317,15 @@ static int tegra_sflash_start_transfer_one(struct 
spi_device *spi,
return  tegra_sflash_start_cpu_based_transfer(tsd, t);
 }
 
+static int tegra_sflash_setup(struct spi_device *spi)
+{
+   struct tegra_sflash_data *tsd = spi_master_get_devdata(spi-master);
+
+   /* Set speed to the spi max fequency if spi device has not set */
+   spi-max_speed_hz = spi-max_speed_hz ? : tsd-spi_max_frequency;
+   return 0;
+}
+
 static int tegra_sflash_transfer_one_message(struct spi_master *master,
struct spi_message *msg)
 {
@@ -492,6 +499,7 @@ static int tegra_sflash_probe(struct platform_device *pdev)
 
/* the spi-mode bits understood by this driver: */
master-mode_bits = SPI_CPOL | SPI_CPHA;
+   master-setup = tegra_sflash_setup;
master-transfer_one_message = tegra_sflash_transfer_one_message;
master-num_chipselect = MAX_CHIP_SELECT;
master-bus_num = -1;
diff --git a/drivers/spi/spi-tegra20-slink.c b/drivers/spi/spi-tegra20-slink.c
index 651167f..29039f1 100644
--- a/drivers/spi/spi-tegra20-slink.c
+++ b/drivers/spi/spi-tegra20-slink.c
@@ -728,9 +728,7 @@ static int tegra_slink_start_transfer_one(struct spi_device 
*spi,
unsigned long command2;
 
bits_per_word = t-bits_per_word;
-   speed = t-speed_hz ? t-speed_hz : spi-max_speed_hz;
-   if (!speed)
-   speed = tspi-spi_max_frequency;
+   speed = t-speed_hz;
if (speed != tspi-cur_speed) {
clk_set_rate(tspi-clk, speed * 4);
tspi-cur_speed = speed;
@@ -841,6 +839,8 @@ static int tegra_slink_setup(struct spi_device *spi)
 
BUG_ON(spi-chip_select = MAX_CHIP_SELECT);
 
+   /* Set speed to the spi max fequency if spi device has not set */
+   spi-max_speed_hz = spi-max_speed_hz ? : tspi-spi_max_frequency;
ret = pm_runtime_get_sync(tspi-dev);
if (ret  0) {
dev_err(tspi-dev, pm runtime failed, e = %d\n, ret);
-- 
1.7.1.1


--
Master HTML5, CSS3, ASP.NET, MVC, AJAX, Knockout.js, Web API and
much more. Get web development skills now with LearnDevNow -
350+ hours of step-by-step video tutorials by Microsoft MVPs and experts.
SALE $99.99 this month only -- learn more at:
http://p.sf.net/sfu/learnmore_122812
___
spi-devel-general mailing list
spi-devel-general@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/spi-devel-general


[PATCH] spi/s3c64xx: Complain if we fail to set a transfer speed

2013-01-04 Thread Mark Brown
Signed-off-by: Mark Brown broo...@opensource.wolfsonmicro.com
---
 drivers/spi/spi-s3c64xx.c |2 ++
 1 file changed, 2 insertions(+)

diff --git a/drivers/spi/spi-s3c64xx.c b/drivers/spi/spi-s3c64xx.c
index ad93231..6495352 100644
--- a/drivers/spi/spi-s3c64xx.c
+++ b/drivers/spi/spi-s3c64xx.c
@@ -957,6 +957,8 @@ static int s3c64xx_spi_setup(struct spi_device *spi)
if (spi-max_speed_hz = speed) {
spi-max_speed_hz = speed;
} else {
+   dev_err(spi-dev, Can't set %dHz transfer speed\n,
+   spi-max_speed_hz);
err = -EINVAL;
goto setup_exit;
}
-- 
1.7.1.1


--
Master HTML5, CSS3, ASP.NET, MVC, AJAX, Knockout.js, Web API and
much more. Get web development skills now with LearnDevNow -
350+ hours of step-by-step video tutorials by Microsoft MVPs and experts.
SALE $99.99 this month only -- learn more at:
http://p.sf.net/sfu/learnmore_122812
___
spi-devel-general mailing list
spi-devel-general@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/spi-devel-general


[PATCH 1/2] spi: make sure all transfer has proper speed set

2013-01-04 Thread Laxman Dewangan
When spi client does the spi transfer and if it does not set
the speed for each transfer then set it as default
of spi device in spi core before calling low level transfer.

This will remove the extra check in low level driver for setting
speed.

Signed-off-by: Laxman Dewangan ldewan...@nvidia.com
---
 drivers/spi/spi.c |6 --
 1 files changed, 4 insertions(+), 2 deletions(-)

diff --git a/drivers/spi/spi.c b/drivers/spi/spi.c
index 19ee901..9676a29 100644
--- a/drivers/spi/spi.c
+++ b/drivers/spi/spi.c
@@ -1366,12 +1366,14 @@ static int __spi_async(struct spi_device *spi, struct 
spi_message *message)
}
 
/**
 * Set transfer bits_per_word as spi device default if it is not
 * set for this transfer.
 */
list_for_each_entry(xfer, message-transfers, transfer_list) {
if (!xfer-bits_per_word)
xfer-bits_per_word = spi-bits_per_word;
+   if (!xfer-speed_hz)
+   xfer-speed_hz = spi-max_speed_hz;
}
 
@@ -1366,12 +1366,14 @@ static int __spi_async(struct spi_device *spi, struct 
 
/**
-* Set transfer bits_per_word as spi device default if it is not
-* set for this transfer.
+* Set transfer bits_per_word and max speed as spi device default if
+* it is not set for this transfer.
 */
list_for_each_entry(xfer, message-transfers, transfer_list) {
message-spi = spi;
-- 
1.7.10.4


--
Master HTML5, CSS3, ASP.NET, MVC, AJAX, Knockout.js, Web API and
much more. Get web development skills now with LearnDevNow -
350+ hours of step-by-step video tutorials by Microsoft MVPs and experts.
SALE $99.99 this month only -- learn more at:
http://p.sf.net/sfu/learnmore_122812
___
spi-devel-general mailing list
spi-devel-general@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/spi-devel-general


Diminuez vos Mensualités - Etude GRATUITE

2013-01-04 Thread Kredity par Galerie des Marques
Pour voir le message, veuillez utiliser un lecteur de mail compatible HTML

Lien miroir : 
http://m10-fr.com/mc10_m/YT04JmI9Mjg5NTQmYz0xOTYxNjQxJmQ9MjAxMy0wMS0wNSAwMDo1MDowMSZlPTEmaD0yODk1MiZmPTI4OTU0Jmc9Mjg5NTQ=

Lien de désinscription : 
http://m10-fr.com/mc10_unsub/YT04JmI9Mjg5NTQmYz0xOTYxNjQxJmQ9MjAxMy0wMS0wNSAwMDo1MDowMSZlPTEmaD0yODk1MiZmPTI4OTU0Jmc9Mjg5NTQ=


--
Master HTML5, CSS3, ASP.NET, MVC, AJAX, Knockout.js, Web API and
much more. Get web development skills now with LearnDevNow -
350+ hours of step-by-step video tutorials by Microsoft MVPs and experts.
SALE $99.99 this month only -- learn more at:
http://p.sf.net/sfu/learnmore_122812
___
spi-devel-general mailing list
spi-devel-general@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/spi-devel-general